﻿namespace Ecng.Trading.Xaml
{
	using System;
	using System.Collections.Generic;
	using System.Windows.Media;
	using System.Windows.Media.Imaging;

	using Ecng.Collections;
	using Ecng.Trading.BusinessEntities;

	using Visifire.Charts;

	/// <summary>
	/// Графический компонент отображения свечек.
	/// </summary>
	public partial class CandleChart
	{
		private readonly Dictionary<Candle, DataPoint> _candles = new Dictionary<Candle, DataPoint>();

		/// <summary>
		/// Создать объект класса <see cref="CandleChart"/>.
		/// </summary>
		public CandleChart()
		{
			InitializeComponent();
		}

		/// <summary>
		/// Нарисовать свечки.
		/// </summary>
		/// <param name="candles">Свечки, которые необходимо нарисовать.</param>
		public void DrawCandles<T>(IEnumerable<T> candles)
			where T : Candle
		{
			if (candles == null)
				throw new ArgumentNullException("candles");

			foreach (var candle in candles)
			{
				var point = _candles.TryGetValue(candle);

				if (point == null)
				{
					point = UpdatePointByCandle(new DataPoint(), candle);
					_candles.Add(candle, point);
					_candleDataSeries.DataPoints.Add(point);
				}
				else
					UpdatePointByCandle(point, candle);
			}
		}

		/// <summary>
		/// Стереть все нарисованные свечки.
		/// </summary>
		public void ClearCandles()
		{
			_candles.Clear();
			_candleDataSeries.DataPoints.Clear();
		}

		/// <summary>
		/// Нарисовать сделки.
		/// </summary>
		/// <param name="trades">Сделки, которые необходимо нарисовать.</param>
		public void DrawTrades(IEnumerable<MyTrade> trades)
		{
			if (trades == null)
				throw new ArgumentNullException("trades");

			//foreach (var trade in trades)
			//{
			//    var isBuy = trade.Order.Direction == OrderDirections.Buy;

			//    var point = new DataPoint
			//    {
			//        XValue = trade.Trade.Time,
			//        YValue = trade.Trade.Price,
			//        Color = new ImageBrush(new BitmapImage(new Uri(isBuy ? "buy.png" : "sell.png", UriKind.RelativeOrAbsolute)))
			//    };

			//    (isBuy ? _buyDataSeries : _sellDataSeries).DataPoints.Add(point);
			//}
		}

		/// <summary>
		/// Нарисовать заявки.
		/// </summary>
		/// <param name="orders">Заявки, которые необходимо нарисовать.</param>
		public void DrawOrders(IEnumerable<Order> orders)
		{
			if (orders == null)
				throw new ArgumentNullException("orders");
		}

		private static DataPoint UpdatePointByCandle(DataPoint point, Candle candle)
		{
			if (point == null)
				throw new ArgumentNullException("point");

			if (candle == null)
				throw new ArgumentNullException("candle");

			//if (point.XValue != null && (DateTime)point.XValue != candle.Time)
			point.XValue = candle.Time;
			point.YValue = candle.TotalVolume;
			point.YValues = new[] { candle.OpenPrice, candle.ClosePrice, candle.HighPrice, candle.LowPrice };
			return point;
		}
	}
}