﻿namespace Ecng.Trading.Xaml
{
	using System;
	using System.Collections.Generic;
	using System.Windows.Controls;

	using Ecng.Collections;
	using Ecng.Trading.BusinessEntities;
	using Ecng.Xaml;

	/// <summary>
	/// Комбо элемент для выбора портфеля.
	/// </summary>
	public class PortfolioComboBox : ComboBox
	{
		private readonly ThreadSafeObservableCollection<Portfolio> _portfolios = new ThreadSafeObservableCollection<Portfolio>();

		/// <summary>
		/// Создать комбо.
		/// </summary>
		public PortfolioComboBox()
		{
			base.DisplayMemberPath = "Name";
			base.ItemsSource = _portfolios;
		}

		private ITrader _trader;

		/// <summary>
		/// Шлюз к торговой системе.
		/// </summary>
		public ITrader Trader
		{
			get { return _trader; }
			set
			{
				if (_trader != value)
				{
					if (_trader != null)
					{
						_trader.NewPortfolios -= OnNewPortfolios;
						_portfolios.Clear();
					}

					_trader = value;

					if (_trader != null)
					{
						AddNewPortfolios(_trader.Portfolios);
						_trader.NewPortfolios += OnNewPortfolios;	
					}
				}
			}
		}

		/// <summary>
		/// Выбранный портфель.
		/// </summary>
		public Portfolio SelectedPortfolio
		{
			get { return (Portfolio)base.SelectedItem; }
			set { base.SelectedItem = value; }
		}

		private void OnNewPortfolios(IEnumerable<Portfolio> portfolios)
		{
			AddNewPortfolios(portfolios);
		}

		private void AddNewPortfolios(IEnumerable<Portfolio> portfolios)
		{
			if (portfolios == null)
				throw new ArgumentNullException("portfolios");

			_portfolios.AddRange(portfolios);
		}
	}
}